@@ -30,6 +30,8 @@ class CNC:
 
     def message_callback(self, message):
         if message and message["command"] and message["command"] != "":
+            if message["command"] == "service:machine:path":
+                self.framework.machine.machine_path = message["data"]
             if message["command"] == "desktop:control:device:estop":
                 self.status.api.poll()
                 if self.status.api.task_state == linuxcnc.STATE_ESTOP:
@@ -60,10 +62,28 @@ class CNC:
                         self.command.home_axis(value)
 
             if message["command"] == "desktop:control:jog:start":
-                pass
+                axis = message["data"]["axis"]
+                speed = message["data"]["speed"]
+                jog_mode = self.command.get_jog_mode()
+                if jog_mode:
+                    axis = self.framework.machine.get_num_axis(axis)
+                else:
+                    axis = self.framework.machine.get_num(axis)
+                speed = speed / 60
+                increment = message["data"]["increment"]
+                if increment == -1:
+                    self.command.jog_continuous(axis, speed, jog_mode)
+                else:
+                    self.command.jog_increment(axis, speed, increment, jog_mode)
 
             if message["command"] == "desktop:control:jog:stop":
-                pass
+                axis = message["data"]["axis"]
+                jog_mode = self.command.get_jog_mode()
+                if jog_mode:
+                    axis = self.framework.machine.get_num_axis(axis)
+                else:
+                    axis = self.framework.machine.get_num(axis)
+                self.command.jog_stop(axis, jog_mode)
 
             if message["command"] == "desktop:control:device:start":
                 self.status.api.poll()
