@@ -10,16 +10,18 @@ class Machine:
         self.framework = framework
         self.user = "armcnc"
         self.axis = []
+        self.axis_tmp = ""
         self.is_alive = False
         self.info = None
-        self.axes_tmp = ""
+        self.machine_path = ""
+        self.workspace = "/opt/armcnc"
 
     def get_num_axis(self, axis):
-        self.axes_tmp = ''.join(self.axis)
-        num = self.axes_tmp.find(axis.upper())
+        self.axis_tmp = ''.join(self.axis)
+        num = self.axis_tmp.find(axis.upper())
         return num
 
     def get_num(self, axis):
-        self.axes_tmp = "XYZABCUVW"
-        num = self.axes_tmp.find(axis.upper())
+        self.axis_tmp = "XYZABCUVW"
+        num = self.axis_tmp.find(axis.upper())
         return num
